#
# spec file for package python3-pyOCD
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           python3-pyOCD
Version:        0.8.0
Release:        1.6
License:        Apache-2.0
Summary:        CMSIS-DAP debugger for python
Url:            https://github.com/mbedmicro/pyOCD
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/p/pyOCD/pyOCD-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  intelhex
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       python3-usb
Requires:       intelhex
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
On-chip debugger and flasher tool for ARM microcontrollers.

%prep
%setup -q -n pyOCD-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in pyocd-flashtool pyocd-gdbserver pyocd-tool ; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py3_ver}
    touch %{buildroot}%{_sysconfdir}/alternatives/$p
    ln -s %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
done

%post
for p in pyocd-flashtool pyocd-gdbserver pyocd-tool ; do
    update-alternatives --install %{_bindir}/$p $p %{_bindir}/$p-%{py3_ver} 30
done

%preun
if [ $1 -eq 0 ] ; then
    for p in pyocd-flashtool pyocd-gdbserver pyocd-tool ; do
	update-alternatives --remove $p %{_bindir}/$p-%{py3_ver}
    done
fi


%files
%defattr(-,root,root,-)
%{python3_sitelib}/*

%doc README.rst LICENSE
%{_bindir}/pyocd-flashtool-%{py3_ver}
%{_bindir}/pyocd-flashtool
%{_bindir}/pyocd-gdbserver-%{py3_ver}
%{_bindir}/pyocd-gdbserver
%{_bindir}/pyocd-tool-%{py3_ver}
%{_bindir}/pyocd-tool
%ghost %{_sysconfdir}/alternatives/pyocd-flashtool
%ghost %{_sysconfdir}/alternatives/pyocd-gdbserver
%ghost %{_sysconfdir}/alternatives/pyocd-tool

%changelog
* Mon Sep 26 2016 arun@gmx.de
- specfile:
  * change from zip to tar.gz
- update to version 0.8.0:
  * Make cmsis-svd optional
  * Add support for the NCS36510
  * pyusb: catch ValueError when fetching the product id
  * Fix s31 bitsize
  * Added comment about keeping board list sorted by ID.
  * Add several board IDs.
  * Added Hexiwear, corrected TWR-KE18F name.
  * Added TWR-KE18F160M target.
  * Analyzer and double buffering support for KE15Z7.
  * Added FRDM-KE15Z.
  * Added comment to Flash_kl28z describing why the target clock is
    changed.
  * Restore some additional code acidentally removed from
    flash_kl28z.py
  * Added FRDM-KL27Z to board table and added test binary.
  * Updated mbed board ID table.
  * Restored clock adjustments to Flash_kL28z.
  * Fix flash algo to support KL28Z 1.1 (pfsize changed)
  * Cleaned up and sorted board IDs table.
  * Updated K66F flash algo and added test binary.
  * Added some missing SVD files and missing SVDFile class imports.
  * FRDM-KW40Z support.
  * Removed KL27Z6464 target and cleaned up boards list.
  * Added numerous Kinetis targets.
  * Display a warning for unsupported boards
  * Add lpc4088 support
  * Properly propagate breakpoint errors
  * Fix breakpoints on devices without memory map
  * Add extra checking when processing the rom table
  * Check that we don't read past the end of a ROM table.
  * Fix travis failures
  * Review changes for ROM table optimization and deferred transfer
    enabling.
  * Enable deferred transfers by default.
  * Optimized reading of ROM table.
  * Extend flash test to cover consecutive regions
  * One commit for architectural changes
  * Pull changes in architecture branch to master
  * Add dap_args passing in pyocd-tool
  * Fix error when -da argument is not set
  * Add missing imports
  * Fix import
  * Websocket interface Passing arguments to pyDAPAccess
* Wed May 25 2016 arun@gmx.de
- update to version 0.7.1:
  * Removed not working reset code for nRF52.
  * Added nRF52-DK board to mbed boards. Added test blinky binary for
    nRF52-DK.
  * Fix hanging GDB when continuing after a hardfault
  * add nrf51's UICR to its memory map
  * Suppress test exception when USB is unavailable
  * Adding Travis CI config
  * Removing __init__ files
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Mar 19 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.7.0:
  * Add support for Linux in test scripts
  * Fix bug with missing product string on Linux
  * Catch exception when reading prod string in pyusb
  * Update USB to use prod string rather than VID/PID
  * flash_tool.py: Return if there is no board connected
  * Create test summary file for CI
  * Increase test result output width
  * Add support for the LPCXpresso824-MAX
  * Dynamically determine target info for testing
  * Add support for the lpc824
  * Fix programming on KL05
  * Add support for additional boards
  * add missing prefix
  * Fixed an issue with the change to CMSIS_DAP_Protocol.dapInfo().
  * Created a test for the JSON list output from pyocd-gdbserver.
  * Created .gitignore in test/ dir to exclude gdb test related files.
  * Fixed JSON output from pyocd-gdbserver.
  * Improved hidapi USB backend.
  * Corrected a couple typos in pyDAPAccess.
  * Fix CMSIS_DAP_Protocol.dapInfo().
  * Add support for microbit
  * Gracefully handle unsupported boards
  * Substitute raise Exception for an assert. More convenient when
    checking parameter validity.
  * Fixed error. When both end and length parameters to
    MemoryRegion.containsRange() are not given, None was used in an
    arithmetic expression.
  * changed reset to always do a reset halt; removed non-functional
    resume
  * removed mon 'reg' cmd; removed caching of idcode
  * minor aesthetic change
  * added 'init' and 'reset' functionality to gdbserver
  * Fix problems found from code review
  * Restructure deferred transfers to use callbacks
  * Add docstrings and exception hierarchy
  * Rename pyDAPLink to pyDAPAccess and modularize
  * Refactor pyOCD in preperation for pyDapLink
* Sat Oct 31 2015 arun@gmx.de
- update to version 0.6.1:
  * protect against re-initing already initd sockets
  * Fix exception when using the max32600
  * Removed extraneous import of socket that sneaked in.
  * Default to disallowing remote TCP/IP connections.
  * JSON data changes.
  * Better board info string.
  * Updated json output format for gdbserver.
  * Set logging level to fatal when output lists from pyocd-gdbserver.
  * Added --list-targets and --json options to pyocd-gdbserver.
  * Add return values for continuous integration
  * Fail immediately when USB backend is missing
  * Update to latest pywinusb to bring in fixes
  * Add support for the lpc11xx_32
  * Add support for the nrf52
* Sun Oct 25 2015 arun@gmx.de
- update to version 0.6.0:
  * Remove Cython as a setup dependency for Mac
  * added [] to handle_halt call; fixes crash with -H option
  * board.py: Removed reference to "chooseInterface"
  * Fix #181 - update authors
  * Add gdb_test to the automated test suite
  * Add script for GDB testing
  * Rescope transport constants and exceptions
  * Rescope const values for Target and FlashBuilder
  * Fix errors found by the pyDev eclipse plugin
  * Run code auto formatting from pyDev in Eclipse
  * Move Cortex-M specific registers into CortexM
  * Review comment changes.
  * Fixed printing of None if no echo command is given pyocd-gdbserver.
  * Improvements to GDBServer main loop.
  * Got non-stop mode working with command line gdb.
  * GDB server non-stop mode.
  * Basic gdb server threads xml reporting.
* Sun Sep 27 2015 arun@gmx.de
- update to version 0.5.1:
  * Adding Cython as a setup dependency for Mac
  * Improve callstack shown on crash
  * Update pywinusb backend and add timeout
* Sun Aug 23 2015 arun@gmx.de
- update to version 0.5.0:
  * Fix pyusb dependency
  * Fix TabError
  * Review fixes for semihosting.
  * Check for an existing breakpoint before setting one.
  * Fixed hw breakpoint bug introduced with sw breakpoints.
  * Software breakpoints.
  * More semihosting unit tests and minor fixes.
  * Fixes for semihosting bugs identified by unit tests.
  * Semihosting unit test.
  * Restored pyocd-gdbserver --version option lost in merge from master.
  * Fixed memory write command in pyocd-tool.
  * Semihost and GDB server shutdown handling and cleanup.
  * fixed setuptools_scm name
  * Semihosting bug fixes and improvements.
  * Semihosting cleanup.
  * GDB server tool improvements and semihosting support.
  * Semihosting telnet console input.
  * GDB server remote command handler.
  * GDB server syscall semihost handler integration.
  * Flushing out semihosting.
  * Semihosting telnet server and I/O handler classes.
  * Renamed GDBServer.performFileIO() to syscall().
  * Refactored GDB server packet I/O into separate thread.
  * GDBServer file I/O and semihosting fixes.
  * Fixes for GDBServer packet send and receive.
  * Added GDBServer packet log option.
  * Continued work on semihosting.
  * Refactor GDBServer packet send and receive.
  * Trailing whitespace cleanup in target and gdbserver.
  * Commented out unaligned mem read/write ragged edge debug logs in CortexM.
  * Initial semihosting support.
  * Added my dev and windev virtualenvs to gitignore.
* Tue Jul 21 2015 arun@gmx.de
- specfile:
  * removed fix for wrong setuptools_scm name
- update to version 0.4.5:
  * Fixed memory write command in pyocd-tool.
  * fixed setuptools_scm name
  * Removed time of last packet attributes.
  * Update tests to use getPageInfo
  * Fixed pyocd-tool merge ident issues, added basic command test script.
  * testing: add notes on getting code coverage results
  * conversion: update names based on code review
  * tests: add initial unittests and related infrastructure
  * Added 'map' command to pyocd-tool.
  * Converted W7500 mem map XML to mem map objects.
  * Replaced gdb server packet send queue with immediate socket writes.
  * Minor gdb server fix and cleanup.
  * Removed ack return value from handleMsg() and related GDBServer methods.
  * Enhancements to GDB server I/O thread.
  * Refactored GDB server packet I/O into separate thread.
  * Fixes for GDBServer packet send and receive.
  * Added GDBServer packet log option.
  * Refactor GDBServer packet send and receive.
  * Trailing whitespace cleanup in target and gdbserver.
  * Removed 'page_size' from flash algo dicts and Flash class.
  * Review comment fixes for memory maps.
  * ROM memory regions.
  * Updated GDBServer to use the getMemoryMapXML() method of Target.
  * Added ability to iterate over the memory map and fixed region end addr.
  * Making use of the memory map in Flash.
  * Fixed FlashRegion not passing blocksize to MemoryRegion constructor.
  * Extended pyocd.py to handle writing to flash is sub-page sizes.
  * Replaced fixed memory map XML with memory map objects.
* Thu Jun 18 2015 arun@gmx.de
- specfile:
  * add requirement for setuptools_scm, intelhex
  * added README.rst and LICENSE as %%doc
- update to version 0.4.4:
  * Reverted platform-version specific install_requires
  * pyocd-tool and flash-tool improvements
- changes from version 0.4.3:
  * avoid broken setuptools_scm versions
  * fix conversion errors
  * align import to pep8 with absolute imports.
  * convert readme to rst
  * Modified source code
  * rebase on top of the master and then added target for W7500 of WIZnet
  * Missed replacing interface arg with self for a couple methods in CMSIS_DAP_Protocol.
  * Removed 'dap' prefix from CMSIS_DAP_Protocol method names.
  * Refactored cmsis_dap_core functions into a CMSIS_DAP_Protocol class.
  * add missing dependency on intelhex
  * add version to command line tools
  * convert to setuptools_scm
  * modernize setup
* Mon Jun 15 2015 arun@gmx.de
- specfile:
  * added setuptools
  * created update-alternatives for new binaries
- update to version 0.4.2:
  * Fix Nordic nRF51822 board to work on Linux
  * Fix halting target in gdb_server.py
  * docs: update readme with additional installation information
  * scripts: modify flashtool and pyocd to support entry point protocol
  * build: update/simplify instructions for building pyinstaller packages
  * gdb: install a 'pyocd' executable on installation that runs gdb server
  * docs: update readme with simplified installation instructions
  * install: declare dependencies for platforms in setup.py
  * Add double buffer support to remaining targets
  * GDBServer no ack mode support.
  * Removed a couple debug prints.
  * Added missing flush to GDBServer.writeMemoryHex().
  * Minor improvements to flash builder changes.
* Sat May 30 2015 arun@gmx.de
- update to version 0.4.1:
  * Setup - v0.4.1, fixing utility package
- changes from version 0.4.0:
  * Enabled deferred transfers in flash_tool.py
  * Add fast verify programming option
  * Update gdb_server.py and flash_tool.py arguments
  * Update handling of GDB breakpoints
  * Rebuild nrf51 flash algo and add erase sector
  * Remove the script flash_nrf51.py
  * Add option to debug flash algorithm
  * Fix programming when reset handler is non-thumb
  * Add support for the nRF51-DK
  * Some gdb server logging changes.
  * Enable multiple packets for HidApiUSB.
  * Moved hexEncode/hexDecode from gdbserver to conversion.
  * GDB server improvements.
  * Removed Kinetis.unlockFlash() method.
  * Minor bug fixes and logging improvements.
  * Removed unnecessary __init__.py in root dir.
  * Added KL28 to cortex_test.py and fixed an issue.
  * Fixed merge indent issues in cortex_m.py.
  * Corrected gdb_server.py path in HOW_TO_BUILD.md.
  * Few more minor fixes and improvements
  * Added missing stdout flush to gdbserver and flash_tool.
  * Changes based on review comments.
  * Added missing USB RAM memory map entry for KL28Z.
  * Some minor fixes.
  * Added pyocd.py script for low level control of targets.
  * Moved all value conversion functions into new utility.conversion submodule.
  * Added KL28Z support.
  * Added auto test results to gitignore and added editorconfig.
  * Fix for #138 - length parameter was removed
  * Optimize cortex_m.py for deferred transfers
  * Add deferred transfer mode for speed boost
  * Update speed_test.py to include USB speed tests
  * Speed up flashing by only writing to some regs
  * Add common function call to flash.py
  * Add cortex_test.py
  * Improve performance data reported by tests
  * Modify dapTransfer so TransferError is thrown
  * Pad write buffer to endpoint size rather than hard-code 64
  * Choose endpoints by direction rather than fixed order.
  * Map boards to board info rather than to target
  * Fix MAXWSNENV and MAX32600MBED
  * Added MAXWSNENV and MAX32600MBED to flash_test.py
  * Fix crash when loading multiple times from GDB
  * Add additional registers to GDB server
  * Prevent mon commands from leaving target running
  * Add generic Cortex-M target
  * Refactoring for PyUSB backend
  * Use AHB IDR to determine auto increment size
* Wed Apr 22 2015 arun@gmx.de
- update to version 0.3.3:
  * Fix automated test crash when no log file exists
  * Add flash_test.py to the automated test list
  * Compute CRCs to analyze flash faster
  * Update flash tool to add featues and increase perf
  * Update gdbserver to support more generic programming
  * Allow differing page sizes on LPC1768
  * Remove flash_start parameter from flashing functs
  * Speed up and unify flash programming
  * Remap flash to user code after reset on LPC
  * Fix hidapi back end
* Fri Apr 10 2015 arun@gmx.de
- update to version 0.3.2:
  * LPC1768 has both 4k and 32k pages
  * dded support for JTAG only targets.
  * Add recommended Eclipse setup to README.MD
  * Add lpc800 and k64f support to speed_test
  * Add support for automated testing
  * Fix bugs and improve MbedBoard class
  * Adding Maxim Integrated MAXWSNENV and MAX32600MBED targets.
  * Added Vendor commands.
* Sun Mar 22 2015 arun@gmx.de
- update to version 0.3.1:
  * Fix LPC sector erase
  * Fix gdb server crash when reading invalid addr
  * Fix monitor commands with OpenOCD eclipse plugin
  * Exit GDB server when GDB client detaches
  * Change reset to use software reset by default
  * Create script to measure read/write speed
  * Improve pyusb speed by creating reader thread
  * Improve dapTransfer speed by queuing packets
* Sat Feb 14 2015 arun@gmx.de
- specfile: pypi changed from tar.gz to zip, changed specfile accordingly
- update to version 0.3:
  * New release package - 0.3
  * add Seeed Arch BLE board and Seeed Tiny BLE board
  * Enable eraseAll functionality for LPC4330
  * LPC4330 resetStopOnReset() needs to init sp & pc
  * Fix known LPC4330 flashing issues in pyOCD
  * Add LPC4330 (Micromint Bambino) support
  * Switch from 'S' to 'T' GDB responses
  * Fix FPU register write
  * Add partial support for software breakpoints
  * Add SWD frequency option to GDB server
  * sleep() calls added latency to single stepping
  * Lower CPU usage
  * Better handling for getTargetXML
  * Enable read/write of FPU registers from GDB
  * Replace hardfault breakpoint with vector catch
  * Disable stepping into interrupts by default
  * Fix incorrect GDB step and resume behavior
  * modify begin_data/begin_stack for 4K RAM stm32f051 chip
  * Fix SWD fault when connecting to locked Kinetis
  * Add support STM32f051 chip and fixed clocks running issue when
    debug halt on stm32f103rc
  * Add support for data breakpoints
  * Add with statement to prevent hang in gdb_server
  * Allow GDB server to recover from SWD faults
  * Update README.md to an actively developed fork
  * Improve handling of keyboard exceptions
  * Improve handling of blank and locked Kineits parts
  * Add 'with' support to board
  * Adjust K64F target file memory configuration to match K64F
    datasheet.
  * added use 2to3
  * using Cortex-M default function for
    reset()/step()/resetStopOnReset()
  * fixed reset()/resetStopOnReset() function because of cortex_m.py
    changed
  * Add support STM32F103RC chip
  * Fix incorrect installation command for Mac.
  * added improvements to readme file
  * Update README.md with new changes
  * Modify resetStopOnReset to use vector catch
  * Flash: K22F flash blob update
  * Flash: Kinetis flash bob update
  * Add program/erase page test to basic_test.py
  * Check the return value of flash operations
  * Update gdbserver to detect starting flash address
  * Update LPC1768 methods reset and resetStopOnReset.
  * Add erase page support to flash.py
  * Rename flash_offset to skip_bytes.
  * Align gdbserver options. Rename flash_protect_offset to
    flash_protect. Merge nrf51 gdb server.
  * Fix 'mon help' commands in GDBServer. Cleanup after code review.
  * Fixes for NRF51822: - add options for gdb_server.py: SoftDevice
    flash protection, don't break at ha rd fault handler, correct
    resume procedure, add extra monitor command. - mask interrupt when
    steppi ng. Required for NRF51. Otherwise GDB server can't step if
    any interrupt occured during halted state. In case of nrf51 with
    enabled BLE it happens all the time. - fix nrf51 reset(),
    resetStopResume() functions. - add nrf51 specific gdb_server
    server.
  * Add software reset to Cortex M processors
  * Add resume parameter to Board.uninit
  * Prevent flash security check from locking target
  * Update flash_nrf51822.py. Use actual offset 0x16000. Add "erase",
    "offset" and "skip" options for b inary file for flexible
    operations. Add "list" command line option to list available
    boards. Add boardId to MbedBoard.listConnectedBoards() method.
  * Fix hidapi interface. Return all available boards. Use USB path
    instead of serial number to identify board.
  * Added installation instructions for MacOS.
  * Fix for older versions of HIDAPI (still current in homebrew on
    Mac) which don't support the open me thod.
  * Device needs to be opened before being accessed for read/write.
  * Add halt and resethalt during flash program
  * Update usage of PyOCD to pyOCD
  * Allow target to be explicitly specified
  * Close interface to prevent hanging on windows
  * Fix readMem and writeMem by writing to DP select
  * Change the pyocd-binary link to root dir
  * Added comments and intermediate variables
  * [Tests] KL46Z addition plus exception if board is not supported,
    lpc800 id correction
  * Close the usb interface in gdbserver stop
  * Update README.md
  * Update HOW_TO_BUILD.md
  * modify syntax
  * Add blanks
  * Add the how to build md for pyocd
  * Pyusb backend fix for using EP0
  * [Flash] Revert - length of array in programPage(), which broke
    K64F support
  * Add supportted Mbed platform
  * Enhance the monitor function
  * Updated basic_test.py with NRF51822
  * Added target NRF51822
  * Fix the exception for unknown cmd
  * Fix the deadlock in resume function
  * Add monitor help, reset, halt support to gdbserver
  * Change int2float, float2int of cortex_m for 64bits
  * Replaced unlock_kinetis.py script with more useful flash_tool.py.
  * Updated K22F flash blob.
  * Update all the other kinetis flash blobs
  * Modified a syntax error
  * Update the details about the new test gdb_server.py
  * Fix the interface mismatching of gdb_server.py
  * Fixed a syntax error in chooseBoard
  * fix a bug in mbed.py
  * Fix a syntax error of the chooseBoard parameter
  * delete some unwanted comment
  * change the sleep time back to the origin
  * add a new test case for gdb server
  * Fix a different python hang (on Windows) when an error occurred
    during the flash.init().
  * Fix python hang (on Windows) when an error occurred during the
    initial device init().
  * Remove whitespace
  * Added unlock script for Kinetis devices.
  * Flash driver improvements.
  * Updated Kinetis flash blobs to latest versions as used in
    CMSIS-DAP.
  * Updates to fix syntax and broken example in gdb_test.py
  * Added K22F support.
  * Provide a new parameter in chooseBoard, so if there is more than
    one board, the function will not b e blocked.
  * Fixed the issue #19 and #20
  * Fix the JIRA issue GCC32RM-303
  * Fix the issue of two duplicate print
  * Provide more information in -h for the -d option
  * In python2.6 the INTERFACE[usb_backend].getAllConnectedInterface
    will return None instead of [], so add more condition to avoid it
  * Fix the bug that sometimes the usb-driver will be blocked by
    pyocd, and add board id information in -l option
  * fix some issue in JIRA GCC32RM-298
  * Modified the exception handler to avoid unwanted exception
  * New option feature added.
  * flash_nrf51822.py uses intelhex library instead of
    arm-none-eabi-objcopy to deal with hex file
  * Corrected so that unsupported mbed devices will be detected, and a
    message printed to the log. Rath er than pyOCD raising an
    exception and dying.
  * pyOCD/gdbserver: Fixed index out of range in lastSignal()
  * pyOCD/gdbserver: Fixed XPSR variable name
  * add script to flash nrf51822
  * Correct License Specifier
* Wed Jan  7 2015 afaerber@suse.de
- Initial: v0.2
